struct TokenSymbols {
symbol: String,
enclosing_symbol: Option<String>,
is_inherent_impl: bool,
}Fields
symbol: Stringenclosing_symbol: Option<String>Definition that contains this one. Only set when symbol is local.
is_inherent_impl: boolTrue if this symbol is for an inherent impl. This is used to only emit SymbolInformation
for a struct’s first inherent impl, since their symbol names are not disambiguated.